==> e2e-android-common-util-2.0.0-20190724.082309-129-sources.jar: com/dayouzc/e2e/core/util/EncryptUtils.java <==
package com.dayouzc.e2e.core.util;


/**
 * 加解密相关帮助类
 *
 * @author 何鑫
 * @date 2018/5/24 10:41
 */
public class EncryptUtils {
    public static    String version = "V1.0";		// 加密版本		注：3Des 加密方式
    public static   byte[] encryptKey = "SJdLgViYsZvlwoFDHI1KQMRO".getBytes();		// 加密 Key
    /**
     * 加密 根据加密版本号，返回加密后的字符串
     *
     * @author HanLiang
     * @param encryptVersion
     *            String 加密版本号
     * @param sorceData
     *            String 源字符串 （注：需要加密字符串）
     * @return encryptData String 加密后字符串
     */
    public static String getEncryptData(String encryptVersion, String sorceData) {
        String encryptData = null;

        if (version.equals(encryptVersion)) {
            try {
                encryptData = ThreeDesUtils.encryptMode(
                        encryptKey,
                        sorceData);
            } catch (Exception e) {
                encryptData = null;
            }
        } else {

        }
        return encryptData;
    }

    /**
     * 解密 根据加密版本号，返回解密后的字符串
     *
     * @author HanLiang
     * @param encryptVersion
     *            String 加密版本号
     * @param sorceData
     *            String 源字符串 （注：需要加密字符串）
     * @return decryptData String 解密后字符串
     */
    public static String getDecryptData(String encryptVersion, String sorceData) {
        String decryptData = null;

        if (version.equals(encryptVersion)) {
            try {
                decryptData = ThreeDesUtils.decryptMode(
                        encryptKey,
                        sorceData);
            } catch (Exception e) {
                decryptData = null;
            }
        } else {

        }
        return decryptData;
    }
}

==> e2e-android-common-util-2.0.0-20200604.062313-142-sources.jar: com/dayouzc/e2e/core/util/EncryptUtils.java <==
package com.dayouzc.e2e.core.util;


/**
 * 加解密相关帮助类
 *
 * @author 何鑫
 * @date 2018/5/24 10:41
 */
public class EncryptUtils {
    /** 加密版本		注：3Des 加密方式 */
    public static String version = "V1.0";
    /** 加密 Key */
    public static byte[] encryptKey = "SJdLgViYsZvlwoFDHI1KQMRO".getBytes();

    /**
     * 加密 根据加密版本号，返回加密后的字符串
     *
     * @param encryptVersion String 加密版本号
     * @param sorceData      String 源字符串 （注：需要加密字符串）
     * @return encryptData String 加密后字符串
     * @author HanLiang
     */
    public static String getEncryptData(String encryptVersion, String sorceData) {
        String encryptData = null;

        if (version.equals(encryptVersion)) {
            try {
                encryptData = ThreeDesUtils.encryptMode(
                        encryptKey,
                        sorceData);
            } catch (Exception e) {
                encryptData = null;
            }
        } else {

        }
        return encryptData;
    }

    /**
     * 解密 根据加密版本号，返回解密后的字符串
     *
     * @param encryptVersion String 加密版本号
     * @param sorceData      String 源字符串 （注：需要加密字符串）
     * @return decryptData String 解密后字符串
     * @author HanLiang
     */
    public static String getDecryptData(String encryptVersion, String sorceData) {
        String decryptData = null;

        if (version.equals(encryptVersion)) {
            try {
                decryptData = ThreeDesUtils.decryptMode(
                        encryptKey,
                        sorceData);
            } catch (Exception e) {
                decryptData = null;
            }
        } else {

        }
        return decryptData;
    }
}
